/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.drill.exec.planner.sql;

import com.google.common.collect.ImmutableList;
import org.apache.drill.exec.planner.PartitionLocation;

import java.util.List;

public class HivePartitionLocation implements PartitionLocation {
  private final String partitionLocation;
  private final List<String> partitionValues;

  public HivePartitionLocation(final List<String> partitionValues, final String partitionLocation) {
    this.partitionValues = ImmutableList.copyOf(partitionValues);
    this.partitionLocation = partitionLocation;
  }
  @Override
  public String getPartitionValue(int index) {
    assert index < partitionValues.size();
    return partitionValues.get(index);
  }

  @Override
  public String getEntirePartitionLocation() {
    return partitionLocation;
  }
}
